/**
 * Create an extension for `micromark` to support math when serializing to
 * HTML.
 *
 * > 👉 **Note**: this uses KaTeX to render math.
 *
 * @param {Options | null | undefined} [options]
 *   Configuration.
 * @returns {HtmlExtension}
 *   Extension for `micromark` that can be passed in `htmlExtensions`, to
 *   support math when serializing to HTML.
 */
export function mathHtml(options?: Options | null | undefined): HtmlExtension
export type KatexOptions = import('katex').KatexOptions
export type HtmlExtension = import('micromark-util-types').HtmlExtension
/**
 * Configuration for HTML output.
 *
 * > 👉 **Note**: passed to `katex.renderToString`.
 * > `displayMode` is overwritten by this plugin, to `false` for math in
 * > text, and `true` for math in flow.
 */
export type Options = Omit<KatexOptions, 'displayMode'>
